@@ -77,10 +77,10 @@ enum
 
 static void g_tls_file_database_openssl_file_database_interface_init (GTlsFileDatabaseInterface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (GTlsFileDatabaseOpenssl, g_tls_file_database_openssl, G_TYPE_TLS_DATABASE_OPENSSL,
-                         G_IMPLEMENT_INTERFACE (G_TYPE_TLS_FILE_DATABASE,
-                                                g_tls_file_database_openssl_file_database_interface_init)
-                         )
+G_DEFINE_FINAL_TYPE_WITH_CODE (GTlsFileDatabaseOpenssl, g_tls_file_database_openssl, G_TYPE_TLS_DATABASE_OPENSSL,
+                               G_IMPLEMENT_INTERFACE (G_TYPE_TLS_FILE_DATABASE,
+                                                      g_tls_file_database_openssl_file_database_interface_init)
+                              )
 
 static GHashTable *
 bytes_multi_table_new (void)
